@@ -132,6 +132,7 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_OP,
 	OER_WHICHCOMMAND_DOP,
 	OER_WHICHCOMMAND_VOICE,
+	OER_WHICHCOMMAND_DEVOICE,
 	OER_WHICHCOMMAND_BAN,
 	OER_WHICHCOMMAND_UNBAN,
 	OER_WHICHCOMMAND_BANKICK,
@@ -159,6 +160,7 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_LOGOFF,
 	OER_WHICHCOMMAND_WALL,
 	OER_WHICHCOMMAND_CLONECHANNEL,
+	OER_WHICHCOMMAND_SSTATS,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -327,7 +329,7 @@ enum OER_TIMED_PRIORITIES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-40, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-41, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -409,6 +411,14 @@ struct timed {
         struct timed *next;
 };
 
+struct mmode {
+        time_t at;
+        char *command;
+        char *target;
+        struct mmode *prev;
+        struct mmode *next;
+};
+
 struct ls_wrapstruct {
 	time_t at;
 	char *str1;
@@ -469,6 +479,9 @@ struct server {
 	int registered;
 	int stoned;
 	int linenoise;
+	int rx;
+	int tx;
+	time_t linkup;
         char password[TINYSTRINGLEN + 1];
 	time_t lastping;
 	struct server *prev;
@@ -508,6 +521,7 @@ struct channel {
 	struct authed *autheds;
 	struct topic *topics;
 	struct advert *adverts;
+        struct mmode *mmodes;
 	struct channel *prev;
 	struct channel *next;
 };
@@ -547,6 +561,7 @@ struct state {
 	struct botuser *admins;
 	struct channel *channels;
 	struct maskstruct *trusted;
+	struct maskstruct *services;
 	struct maskstruct *kickreasons;
 	struct server *servers;
 	struct server *current_server;
